/*
 * This file is part of wl-overlay: show overlays with images and text in Wayland
 * Copyright © 2022 Midgard
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * ---
 *
 * The code in this file is based on example code from the Wayland Book (https://wayland-book.com/).
 * This code was licensed to Midgard under the MIT license in an email.
 *
 * Copyright (c) 2021 Drew Devault
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef STATE_H
#define STATE_H

#include "common.h"

struct user_request {
	char *graphics_filename;
	char *text;
	char *font;
	struct color_argb backdrop;
	struct color_argb text_color;
	int border_radius;
	int width;
	int height;
	int padding;
	int time;
};

struct wayland_state {
	/* Globals */
	struct wl_registry *wl_registry;
	struct wl_display *wl_display;
	struct wl_shm *wl_shm;
	struct wl_compositor *wl_compositor;
	struct zwlr_layer_shell_v1 *layer_shell;

	struct wl_seat *wl_seat;
	/* Objects */
	struct wl_surface *wl_surface;
	struct zwlr_layer_surface_v1 *zwlr_surface;
};

struct client_state {
	struct user_request user_request;
	struct wayland_state wl_state;
};

#endif // STATE_H
